.. _api:

=============
API Reference
=============

This page gives an overview of all public grammatica objects, functions and
methods. All classes and functions exposed in ``grammatica.*`` namespace are public.

The following subpackages are public.

- ``grammatica.grammar``: Classes and utilities for creating and manipulating grammars.
- ``grammatica.utils``: Utility functions used throughout the library.

..
    - ``grammatica.errors``: Custom exception and warnings classes that are raised by grammatica.

.. warning::

    The ``grammatica.base``, ``grammatica.grammar.base`` top-level modules are PRIVATE. Stable functionality in such modules is not guaranteed.

.. toctree::

    group/and_
    group/or_
    char_range
    string
    derivation_rule
